==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-negative-volume-index-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { NegativeVolumeIndexIndicator } from "./NegativeVolumeIndexIndicator";
/**
 * Represents a IgxDataChartComponent Negative Volume Index indicator (NVI) series.
 * Default required members: Close, Volume
*
* The `IgxNegativeVolumeIndexIndicatorComponent` (NVI) is a finacial indicator frequently used in combination with the PositiveVolumeIndexIndicator. This calculation can be used to identify bull markets. These two indicators are based on the premise that smart money trades on low volume days and less informed or overly optimistic investors trade on high volume days.
*
* Using this indicator requires setting both the `CloseMemberPath` and `VolumeMemberPath`.
*
* ```html
* <igx-data-chart
*     width=500px
*     height=500px
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
*         dateTimeMemberPath="TimeStamp"
*         #xAxis>
*       </igx-ordinal-time-x-axis>
*     <igx-numeric-y-axis
*        #yAxis></igx-numeric-y-axis>
*     <igx-negative-volume-index-indicator
*        [xAxis]="xAxis"
*        [yAxis]="yAxis"
*        volumeMemberPath="volume"
*        closeMemberPath="close">
*     </igx-negative-volume-index-indicator>
* </igx-data-chart>
* ```
*/
var IgrNegativeVolumeIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrNegativeVolumeIndexIndicator, _super);
    function IgrNegativeVolumeIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrNegativeVolumeIndexIndicator.prototype.createImplementation = function () {
        return new NegativeVolumeIndexIndicator();
    };
    Object.defineProperty(IgrNegativeVolumeIndexIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return IgrNegativeVolumeIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrNegativeVolumeIndexIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-negative-volume-index-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { NegativeVolumeIndexIndicator } from "./NegativeVolumeIndexIndicator";
/**
 * Represents a IgxDataChartComponent Negative Volume Index indicator (NVI) series.
 * Default required members: Close, Volume
*
* The `IgrNegativeVolumeIndexIndicator` (NVI) is a finacial indicator frequently used in combination with the PositiveVolumeIndexIndicator. This calculation can be used to identify bull markets. These two indicators are based on the premise that smart money trades on low volume days and less informed or overly optimistic investors trade on high volume days.
*
* Using this indicator requires setting both the `CloseMemberPath` and `VolumeMemberPath`.
*/
var IgrNegativeVolumeIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrNegativeVolumeIndexIndicator, _super);
    function IgrNegativeVolumeIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrNegativeVolumeIndexIndicator.prototype.createImplementation = function () {
        return new NegativeVolumeIndexIndicator();
    };
    Object.defineProperty(IgrNegativeVolumeIndexIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return IgrNegativeVolumeIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrNegativeVolumeIndexIndicator };
